@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: mb_c.h 9246 2007-07-07 06:40:33Z luks $
+ * $Id: mb_c.h 9932 2008-07-02 06:48:17Z luks $
  */
  
 #ifndef __MUSICBRAINZ3_MB_C_H__
@@ -552,6 +552,14 @@ mb_track_get_num_relations(MbTrack track);
 MB_API MbRelation
 mb_track_get_relation(MbTrack track, int index);
 
+/**
+ * Returns the artist. 
+ *
+ * @see MusicBrainz::Track::getArtist
+ */
+MB_API MbArtist
+mb_track_get_artist(MbTrack track);
+
 /* }}} */
 
 /* {{{ MusicBrainz::ArtistAlias */
