@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: model.h 8466 2006-09-05 08:59:44Z luks $
+ * $Id: model.h 9218 2007-06-25 20:11:09Z luks $
  */
  
 #ifndef __MUSICBRAINZ3_MODEL_H__
@@ -33,6 +33,9 @@
 #include <musicbrainz3/releaseevent.h> 
 #include <musicbrainz3/relation.h> 
 #include <musicbrainz3/user.h> 
+#include <musicbrainz3/tag.h> 
+#include <musicbrainz3/label.h> 
+#include <musicbrainz3/labelalias.h> 
 
 #endif
 
