@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: disc.cpp 9130 2007-05-11 22:55:10Z luks $
+ * $Id: disc.cpp 9189 2007-06-20 19:41:06Z luks $
  */
 
 #include <config.h>
@@ -60,53 +60,10 @@ Disc::~Disc()
 	delete d;
 }
 
-string
-Disc::getId() const
-{
-    return d->id;
-}
-
-void
-Disc::setId(const string &value)
-{
-    d->id = value;
-}
-
-int
-Disc::getSectors() const
-{
-    return d->sectors;
-}
-
-void
-Disc::setSectors(const int value)
-{
-    d->sectors = value;
-}
-
-int
-Disc::getFirstTrackNum() const
-{
-    return d->firstTrackNum;
-}
-
-void
-Disc::setFirstTrackNum(const int value)
-{
-    d->firstTrackNum = value;
-}
-
-int
-Disc::getLastTrackNum() const
-{
-    return d->lastTrackNum;
-}
-
-void
-Disc::setLastTrackNum(const int value)
-{
-    d->lastTrackNum = value;
-}
+SIMPLE_STRING_SETTER_GETTER(Disc, Id, id);
+SIMPLE_INT_SETTER_GETTER(Disc, Sectors, sectors);
+SIMPLE_INT_SETTER_GETTER(Disc, FirstTrackNum, firstTrackNum);
+SIMPLE_INT_SETTER_GETTER(Disc, LastTrackNum, lastTrackNum);
 
 Disc::TrackList &
 Disc::getTracks()
@@ -123,7 +80,7 @@ Disc::addTrack(Disc::Track track)
 Disc *
 MusicBrainz::readDisc(const std::string &deviceName)
 {
-#ifdef HAVE_DISCID
+#ifdef DISCID_FOUND
 	DiscId *discid = discid_new();
 	if (!discid) {
 		throw DiscError("Couldn't create a new DiscId instance.");
