@@ -17,11 +17,12 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: entity.cpp 8466 2006-09-05 08:59:44Z luks $
+ * $Id: entity.cpp 9216 2007-06-25 19:42:20Z luks $
  */
  
 #include <string>
 #include <musicbrainz3/entity.h>
+#include "utils_private.h"
 
 using namespace std;
 using namespace MusicBrainz;
@@ -34,6 +35,7 @@ public:
 	
 	std::string id;
 	RelationList relations;
+	TagList tags;
 };
 
 Entity::Entity(const string &id)
@@ -52,17 +54,7 @@ Entity::~Entity()
 	delete d;
 }
 
-string
-Entity::getId() const
-{
-	return d->id;
-}
-
-void
-Entity::setId(const string &id)
-{
-	d->id = id;
-}
+SIMPLE_STRING_SETTER_GETTER(Entity, Id, id);
 
 RelationList 
 Entity::getRelations(const std::string &targetType,
@@ -116,3 +108,21 @@ Entity::getRelation(int i)
 	return d->relations[i];
 }
 
+int
+Entity::getNumTags() const
+{
+	return d->tags.size();
+}
+
+Tag * 
+Entity::getTag(int i)
+{
+	return d->tags[i];
+}
+
+TagList &
+Entity::getTags()
+{
+	return d->tags;
+}
+
