@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: mbxmlparser.cpp 9218 2007-06-25 20:11:09Z luks $
+ * $Id: mbxmlparser.cpp 9933 2008-07-02 06:56:08Z luks $
  */
  
 // TODO: support for namespaces and full MMD 
@@ -81,7 +81,7 @@ static bool
 getBoolAttr(XMLNode node, string name)
 {
 	const char *value = node.getAttribute(name.c_str());
-	return value ? value == "true" : false;
+	return value ? string(value) == string("true") : false;
 }
 
 static int
