@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: metadata.cpp 8466 2006-09-05 08:59:44Z luks $
+ * $Id: metadata.cpp 9218 2007-06-25 20:11:09Z luks $
  */
  
 #include <musicbrainz3/metadata.h>
@@ -30,12 +30,14 @@ public:
 	MetadataPrivate() :
 		artist(NULL),
 		track(NULL),
-		release(NULL)
+		release(NULL),
+		label(NULL)
 		{}
 	
 	Artist *artist;
 	Track *track;
 	Release *release;
+	Label *label;
 	UserList userList;
 	ArtistResultList artistResults;
 	TrackResultList trackResults;
@@ -58,6 +60,9 @@ Metadata::~Metadata()
 	if (d->release)
 		delete d->release;
 	
+	if (d->label)
+		delete d->label;
+	
 	for (UserList::iterator i = d->userList.begin(); i != d->userList.end(); i++) 
 		delete *i;
 	d->userList.clear();
@@ -127,6 +132,23 @@ Metadata::getRelease(bool remove)
     return ret;
 }
 
+Label * 
+Metadata::getLabel(bool remove)
+{
+	Label *ret = d->label;
+	if (remove)
+		d->label = NULL;
+    return ret;
+}
+
+void 
+Metadata::setLabel(Label *value)
+{
+	if (d->label)
+		delete d->label;
+    d->label = value;
+}
+
 UserList &
 Metadata::getUserList()
 {
