@@ -17,11 +17,12 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: relation.cpp 8466 2006-09-05 08:59:44Z luks $
+ * $Id: relation.cpp 9189 2007-06-20 19:41:06Z luks $
  */
  
 #include <string>
 #include <musicbrainz3/model.h>
+#include "utils_private.h"
 
 using namespace std;
 using namespace MusicBrainz;
@@ -76,29 +77,11 @@ Relation::~Relation()
 	delete d;
 }
 
-string
-Relation::getType() const
-{
-	return d->type;
-}
-
-void
-Relation::setType(const string &value)
-{
-	d->type = value;
-}
-
-string
-Relation::getTargetId() const
-{
-	return d->targetId;
-}
-
-void
-Relation::setTargetId(const string &value)
-{
-	d->targetId = value;
-}
+SIMPLE_STRING_SETTER_GETTER(Relation, Type, type);
+SIMPLE_STRING_SETTER_GETTER(Relation, TargetId, targetId);
+SIMPLE_STRING_SETTER_GETTER(Relation, TargetType, targetType);
+SIMPLE_STRING_SETTER_GETTER(Relation, BeginDate, beginDate);
+SIMPLE_STRING_SETTER_GETTER(Relation, EndDate, endDate);
 
 Relation::Direction
 Relation::getDirection() const
@@ -112,18 +95,6 @@ Relation::setDirection(const Relation::Direction value)
 	d->direction = value;
 }
 
-string
-Relation::getTargetType() const
-{
-	return d->targetType;
-}
-
-void
-Relation::setTargetType(const string &value)
-{
-	d->targetType = value;
-}
-
 Entity *
 Relation::getTarget() const
 {
@@ -148,30 +119,6 @@ Relation::addAttribute(const string &value)
 	d->attributes.push_back(value);
 }
 
-string
-Relation::getBeginDate() const
-{
-	return d->beginDate;
-}
-
-void
-Relation::setBeginDate(const string &value)
-{
-	d->beginDate = value;
-}
-
-string
-Relation::getEndDate() const
-{
-	return d->endDate;
-}
-
-void
-Relation::setEndDate(const string &value)
-{
-	d->endDate = value;
-} 
-
 int
 Relation::getNumAttributes() const
 {
