@@ -17,11 +17,12 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: release.cpp 8788 2007-01-13 22:26:09Z luks $
+ * $Id: release.cpp 9191 2007-06-20 19:55:32Z luks $
  */
  
 #include <string>
 #include <musicbrainz3/model.h>
+#include "utils_private.h"
 
 using namespace std;
 using namespace MusicBrainz;
@@ -43,6 +44,7 @@ const string Release::TYPE_OTHER = NS_MMD_1 + "Other";
 const string Release::TYPE_OFFICIAL = NS_MMD_1 + "Official";
 const string Release::TYPE_PROMOTION = NS_MMD_1 + "Promotion";
 const string Release::TYPE_BOOTLEG = NS_MMD_1 + "Bootleg";	
+const string Release::TYPE_PSEUDO_RELEASE = NS_MMD_1 + "Pseudo-Release";	
 
 class Release::ReleasePrivate
 {
@@ -94,41 +96,10 @@ Release::~Release()
 	delete d;
 }
 
-string
-Release::getTitle() const
-{
-	return d->title;
-}
-
-void
-Release::setTitle(const string &value)
-{
-	d->title = value;
-}
-
-string
-Release::getTextLanguage() const
-{
-	return d->textLanguage;
-}
-
-void
-Release::setTextLanguage(const string &value)
-{
-	d->textLanguage = value;
-}
-
-string
-Release::getTextScript() const
-{
-	return d->textScript;
-}
-
-void
-Release::setTextScript(const string &value)
-{
-	d->textScript = value;
-}
+SIMPLE_STRING_SETTER_GETTER(Release, Title, title);
+SIMPLE_STRING_SETTER_GETTER(Release, TextLanguage, textLanguage);
+SIMPLE_STRING_SETTER_GETTER(Release, TextScript, textScript);
+SIMPLE_STRING_SETTER_GETTER(Release, Asin, asin);
 
 Artist *
 Release::getArtist()
@@ -144,18 +115,6 @@ Release::setArtist(Artist *value)
 	d->artist = value;
 }
 
-string
-Release::getAsin() const
-{
-	return d->asin;
-}
-
-void
-Release::setAsin(const string &value)
-{
-	d->asin = value;
-}
-
 TrackList &
 Release::getTracks()
 {
