@@ -17,11 +17,12 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: track.cpp 8794 2007-01-18 23:37:36Z luks $
+ * $Id: track.cpp 9189 2007-06-20 19:41:06Z luks $
  */
  
 #include <string>
 #include <musicbrainz3/model.h>
+#include "utils_private.h"
 
 using namespace std;
 using namespace MusicBrainz;
@@ -58,17 +59,8 @@ Track::~Track()
 	delete d;
 }
 
-string
-Track::getTitle() const
-{
-    return d->title;
-}
-
-void
-Track::setTitle(const string &value)
-{
-    d->title = value;
-}
+SIMPLE_STRING_SETTER_GETTER(Track, Title, title);
+SIMPLE_INT_SETTER_GETTER(Track, Duration, duration);
 
 Artist *
 Track::getArtist()
@@ -84,18 +76,6 @@ Track::setArtist(Artist *value)
 	d->artist = value;
 }
 
-int
-Track::getDuration() const
-{
-    return d->duration;
-}
-
-void
-Track::setDuration(const int value)
-{
-    d->duration = value;
-}
-
 ReleaseList &
 Track::getReleases()
 {
