@@ -17,11 +17,12 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: user.cpp 8466 2006-09-05 08:59:44Z luks $
+ * $Id: user.cpp 9189 2007-06-20 19:41:06Z luks $
  */
  
 #include <string>
 #include <musicbrainz3/user.h>
+#include "utils_private.h"
 
 using namespace std;
 using namespace MusicBrainz;
@@ -48,17 +49,7 @@ User::~User()
 	delete d;
 }
 
-string
-User::getName() const
-{
-	return d->name;
-}
-
-void
-User::setName(const string &value)
-{
-	d->name = value;
-}
+SIMPLE_STRING_SETTER_GETTER(User, Name, name);
 
 bool
 User::getShowNag() const
