@@ -17,7 +17,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * $Id: utils_private.h 8466 2006-09-05 08:59:44Z luks $
+ * $Id: utils_private.h 9189 2007-06-20 19:41:06Z luks $
  */
  
 #ifndef __MUSICBRAINZ3_UTILSPRIV_H__
@@ -44,4 +44,28 @@ namespace MusicBrainz
 	
 }
 
+#define SIMPLE_STRING_SETTER_GETTER(class, name, name2) \
+	string \
+	class::get##name() const \
+	{ \
+		return d->name2; \
+	} \
+	void \
+	class::set##name(const string &value) \
+	{ \
+		d->name2 = value; \
+	}
+
+#define SIMPLE_INT_SETTER_GETTER(class, name, name2) \
+	int \
+	class::get##name() const \
+	{ \
+		return d->name2; \
+	} \
+	void \
+	class::set##name(const int value) \
+	{ \
+		d->name2 = value; \
+	}
+
 #endif
