@@ -58,7 +58,7 @@
 #ifndef _CRT_SECURE_NO_DEPRECATE
 #define _CRT_SECURE_NO_DEPRECATE
 #endif
-#include <windows.h> // to have IsTextUnicode, MultiByteToWideChar, WideCharToMultiByte
+#include <Windows.h> // to have IsTextUnicode, MultiByteToWideChar, WideCharToMultiByte
                      // to handle unicode files
 #endif
 
@@ -113,7 +113,7 @@ typedef enum TokenTypeTag
     eTokenShortHandClose,   /* "/>"           */
     eTokenClear,
     eTokenError
-} TokenTypeTag;
+};
 
 #define INDENTCHAR    _T('\t')
 
